from dataclasses import dataclass
from enum import Enum
from typing import Optional, Callable, Any, Dict, List, Union, Type

class CheckerTaskResult(Enum):
    CHECKER_TASK_RESULT_OK = "OK"
    CHECKER_TASK_RESULT_MUMBLE = "MUMBLE"
    CHECKER_TASK_RESULT_DOWN = "OFFLINE"
    CHECKER_TASK_RESULT_INTERNAL_ERROR = "INTERNAL_ERROR"

    def __str__(self):
        return self.value

class CheckerTaskType(Enum):
    CHECKER_TASK_TYPE_PUTFLAG = "putflag"
    CHECKER_TASK_TYPE_GETFLAG = "getflag"
    CHECKER_TASK_TYPE_PUTNOISE = "putnoise"
    CHECKER_TASK_TYPE_GETNOISE = "getnoise"
    CHECKER_TASK_TYPE_HAVOC = "havoc"

    def __str__(self):
        return self.value

@dataclass
class CheckerInfoMessage:
    serviceName: str
    flagCount: int
    havocCount: int
    noiseCount: int

@dataclass
class CheckerResultMessage:
    result: str

@dataclass
class EnoLogMessage:
    tool: str
    type: str
    severity: str
    timestamp: str
    module: str
    function: str
    flag: Optional[int]
    flagIndex: Optional[int]
    runId: Optional[int]
    round: Optional[int]
    message: str
    teamName: Optional[str]
    serviceName: str

@dataclass
class CheckerTaskMessage:
    runId: int
    method: str
    address: str
    serviceId: str
    serviceName: str
    teamId: str
    team: str
    relatedRoundId: int
    round: int
    flag: Optional[str]
    flagIndex: Optional[int]

class BrokenServiceException(Exception):
    pass

class OfflineException(Exception):
    pass



import setuptools

with open("README.md", "r") as f:
    long_description = f.read()

with open("requirements.txt", "r") as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name="enochecker_core",
    version="0.1.1",
    author="Trolldemorted",
    author_email="benediktradtke@gmail.com",
    description="Base library for enochecker libs",
    long_description=long_description,
    url="https://github.com/enowars/enochecker_core",
    packages=setuptools.find_packages(),
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        # 'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.7',

    ]
)
